from zshpower import __name__

info = {
    "name": "ZSHPower",
    "description": "ZSHPower is a theme for ZSH with a manager.",
    "pkg_name": __name__,
    "executable": __name__,
    "home_page": "https://github.com/snakypy/zshpower",
    "organization_name": "Snakypy",
    "author": {
        "name": "William C. Canin",
        "email": "william.costa.canin@gmail.com",
        "website": "https://williamcanin.github.io",
        "github": "https://github.com/williamcanin",
    },
    "credence": [
        {
            "my_name": "William C. Canin",
            "email": "william.costa.canin@gmail.com",
            "website": "http://williamcanin.me",
            "locale": "Brazil - SP",
        }
    ],
}
